.. currentmodule:: message_ix_models.testing

Test utilities and fixtures (:mod:`.testing`)
*********************************************

:doc:`Fixtures <pytest:explanation/fixtures>`:

.. autosummary::

   mix_models_cli
   session_context
   test_context
   user_context

:doc:`Marks <pytest:how-to/mark>`:

.. autosummary::

   NIE
   not_ci

Others:

.. autosummary::

   EXPORT_OMIT
   CliRunner
   bare_res
   export_test_data
   pytest_addoption

.. automodule:: message_ix_models.testing
   :members:
